@@ -205,7 +205,7 @@ def generate_yearmonth_monthbin(year, month, monthbin):
 
     return yearmonth_timeperiod
 
-def generate_quarters_or_yearmonths(year_from, year_till, monthbins = None):
+def generate_quarters_or_yearmonths(year_from, year_till, monthbins=None):
     q_or_ym = []
 
     year = int(str(year_from)[:4])
@@ -214,32 +214,37 @@ def generate_quarters_or_yearmonths(year_from, year_till, monthbins = None):
     end_year = int(str(year_till)[:4])
     end_month = int(str(year_till)[4:6])
 
-
     while True:
-      if year <=2015:
-         yearmonth = generate_yearmonth_quaterly(year, month)
-         month = month + 3
-      else:
-         if monthbins is None:
-            yearmonth = generate_yearmonth_monthly(year, month)
-            month = month + 1
-         if monthbins is not None:
-             q_or_ym_bins = []
-             for monthbin in monthbins:
-                yearmonth = generate_yearmonth_monthbin(year, month, monthbin-1)
-                q_or_ym_bins.append(yearmonth)
-                month = month + monthbin
-             return q_or_ym_bins
-      q_or_ym.append(yearmonth)
+        if year <= 2015:
+            yearmonth = generate_yearmonth_quaterly(year, month)
+            month = month + 3
+        else:
+            if monthbins is None:
+                yearmonth = generate_yearmonth_monthly(year, month)
+                month = month + 1
+            if monthbins is not None:
+                q_or_ym_bins = []
+                for monthbin in monthbins:
+                    yearmonth = generate_yearmonth_monthbin(year, month, monthbin - 1)
+                    q_or_ym_bins.append(yearmonth)
+                    month = month + monthbin
 
-      if year == end_year and month > end_month:
-         break
+                    if month > 12:
+                        year += 1
+                        month = 1
 
-      if month > 12:
-         year +=1
-         month =1
-    return
+                    if year == end_year and month > end_month:
+                        return q_or_ym_bins
+                return q_or_ym_bins
+        q_or_ym.append(yearmonth)
 
+        if year == end_year and month > end_month:
+            break
+
+        if month > 12:
+            year += 1
+            month = 1
+    return q_or_ym
 #################################################################################################
 #################################################################################################
 def archive_results(tmp_dir_tpl, src_dst_pairs):
